@@ -1,5 +1,6 @@
 // Copyright (C) 2012 Ryan Curtin
 // Copyright (C) 2012 Conrad Sanderson
+// Copyright (C) 2013 Szabolcs Horvat
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -35,7 +36,7 @@ inline
 hid_t
 get_hdf5_type< unsigned char >()
   {
-  return H5Tcopy(H5T_NATIVE_UCHAR);
+  return arma_H5Tcopy(arma_H5T_NATIVE_UCHAR);
   }
 
 template<>
@@ -43,7 +44,7 @@ inline
 hid_t
 get_hdf5_type< char >()
   {
-  return H5Tcopy(H5T_NATIVE_CHAR);
+  return arma_H5Tcopy(arma_H5T_NATIVE_CHAR);
   }
 
 template<>
@@ -51,7 +52,7 @@ inline
 hid_t
 get_hdf5_type< short >()
   {
-  return H5Tcopy(H5T_NATIVE_SHORT);
+  return arma_H5Tcopy(arma_H5T_NATIVE_SHORT);
   }
 
 template<>
@@ -59,7 +60,7 @@ inline
 hid_t
 get_hdf5_type< unsigned short >()
   {
-  return H5Tcopy(H5T_NATIVE_USHORT);
+  return arma_H5Tcopy(arma_H5T_NATIVE_USHORT);
   }
 
 template<>
@@ -67,7 +68,7 @@ inline
 hid_t
 get_hdf5_type< int >()
   {
-  return H5Tcopy(H5T_NATIVE_INT);
+  return arma_H5Tcopy(arma_H5T_NATIVE_INT);
   }
 
 template<>
@@ -75,7 +76,7 @@ inline
 hid_t
 get_hdf5_type< unsigned int >()
   {
-  return H5Tcopy(H5T_NATIVE_UINT);
+  return arma_H5Tcopy(arma_H5T_NATIVE_UINT);
   }
 
 template<>
@@ -83,7 +84,7 @@ inline
 hid_t
 get_hdf5_type< long >()
   {
-  return H5Tcopy(H5T_NATIVE_LONG);
+  return arma_H5Tcopy(arma_H5T_NATIVE_LONG);
   }
 
 template<>
@@ -91,7 +92,7 @@ inline
 hid_t
 get_hdf5_type< unsigned long >()
   {
-  return H5Tcopy(H5T_NATIVE_ULONG);
+  return arma_H5Tcopy(arma_H5T_NATIVE_ULONG);
   }
 
 
@@ -101,7 +102,7 @@ get_hdf5_type< unsigned long >()
   hid_t
   get_hdf5_type< long long >()
     {
-    return H5Tcopy(H5T_NATIVE_LLONG);
+    return arma_H5Tcopy(arma_H5T_NATIVE_LLONG);
     }
 
   template<>
@@ -109,7 +110,7 @@ get_hdf5_type< unsigned long >()
   hid_t
   get_hdf5_type< unsigned long long >()
     {
-    return H5Tcopy(H5T_NATIVE_ULLONG);
+    return arma_H5Tcopy(arma_H5T_NATIVE_ULLONG);
     }
 #endif
 
@@ -119,7 +120,7 @@ inline
 hid_t
 get_hdf5_type< float >()
   {
-  return H5Tcopy(H5T_NATIVE_FLOAT);
+  return arma_H5Tcopy(arma_H5T_NATIVE_FLOAT);
   }
 
 template<>
@@ -127,7 +128,7 @@ inline
 hid_t
 get_hdf5_type< double >()
   {
-  return H5Tcopy(H5T_NATIVE_DOUBLE);
+  return arma_H5Tcopy(arma_H5T_NATIVE_DOUBLE);
   }
 
 
@@ -147,10 +148,10 @@ inline
 hid_t
 get_hdf5_type< std::complex<float> >()
   {
-  hid_t type = H5Tcreate(H5T_COMPOUND, sizeof(hdf5_complex_t<float>));
+  hid_t type = arma_H5Tcreate(H5T_COMPOUND, sizeof(hdf5_complex_t<float>));
   
-  H5Tinsert(type, "real", HOFFSET(hdf5_complex_t<float>, real), H5T_NATIVE_FLOAT);
-  H5Tinsert(type, "imag", HOFFSET(hdf5_complex_t<float>, imag), H5T_NATIVE_FLOAT);
+  arma_H5Tinsert(type, "real", HOFFSET(hdf5_complex_t<float>, real), arma_H5T_NATIVE_FLOAT);
+  arma_H5Tinsert(type, "imag", HOFFSET(hdf5_complex_t<float>, imag), arma_H5T_NATIVE_FLOAT);
   
   return type;
   }
@@ -162,10 +163,10 @@ inline
 hid_t
 get_hdf5_type< std::complex<double> >()
   {
-  hid_t type = H5Tcreate(H5T_COMPOUND, sizeof(hdf5_complex_t<double>));
+  hid_t type = arma_H5Tcreate(H5T_COMPOUND, sizeof(hdf5_complex_t<double>));
 
-  H5Tinsert(type, "real", HOFFSET(hdf5_complex_t<double>, real), H5T_NATIVE_DOUBLE);
-  H5Tinsert(type, "imag", HOFFSET(hdf5_complex_t<double>, imag), H5T_NATIVE_DOUBLE);
+  arma_H5Tinsert(type, "real", HOFFSET(hdf5_complex_t<double>, real), arma_H5T_NATIVE_DOUBLE);
+  arma_H5Tinsert(type, "imag", HOFFSET(hdf5_complex_t<double>, imag), arma_H5T_NATIVE_DOUBLE);
 
   return type;
   }
@@ -185,68 +186,68 @@ is_supported_arma_hdf5_type(hid_t datatype)
   // start with most likely used types: double, complex<double>, float, complex<float>
   
   search_type = get_hdf5_type<double>();
-  is_equal = ( H5Tequal(datatype, search_type) > 0 );
-  H5Tclose(search_type);
+  is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+  arma_H5Tclose(search_type);
   if (is_equal) { return true; }
   
   search_type = get_hdf5_type< std::complex<double> >();
-  is_equal = ( H5Tequal(datatype, search_type) > 0 );
-  H5Tclose(search_type);
+  is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+  arma_H5Tclose(search_type);
   if (is_equal) { return true; }
   
   search_type = get_hdf5_type<float>();
-  is_equal = ( H5Tequal(datatype, search_type) > 0 );
-  H5Tclose(search_type);
+  is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+  arma_H5Tclose(search_type);
   if (is_equal) { return true; }
   
   search_type = get_hdf5_type< std::complex<float> >();
-  is_equal = ( H5Tequal(datatype, search_type) > 0 );
-  H5Tclose(search_type);
+  is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+  arma_H5Tclose(search_type);
   if (is_equal) { return true; }
   
   
   // remaining supported types: u8, s8, u16, s16, u32, s32, u64, s64, ulng_t, slng_t
   
   search_type = get_hdf5_type<u8>();
-  is_equal = ( H5Tequal(datatype, search_type) > 0 );
-  H5Tclose(search_type);
+  is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+  arma_H5Tclose(search_type);
   if (is_equal) { return true; }
   
   search_type = get_hdf5_type<s8>();
-  is_equal = ( H5Tequal(datatype, search_type) > 0 );
-  H5Tclose(search_type);
+  is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+  arma_H5Tclose(search_type);
   if (is_equal) { return true; }
   
   search_type = get_hdf5_type<u16>();
-  is_equal = ( H5Tequal(datatype, search_type) > 0 );
-  H5Tclose(search_type);
+  is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+  arma_H5Tclose(search_type);
   if (is_equal) { return true; }
   
   search_type = get_hdf5_type<s16>();
-  is_equal = ( H5Tequal(datatype, search_type) > 0 );
-  H5Tclose(search_type);
+  is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+  arma_H5Tclose(search_type);
   if (is_equal) { return true; }
   
   search_type = get_hdf5_type<u32>();
-  is_equal = ( H5Tequal(datatype, search_type) > 0 );
-  H5Tclose(search_type);
+  is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+  arma_H5Tclose(search_type);
   if (is_equal) { return true; }
   
   search_type = get_hdf5_type<s32>();
-  is_equal = ( H5Tequal(datatype, search_type) > 0 );
-  H5Tclose(search_type);
+  is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+  arma_H5Tclose(search_type);
   if (is_equal) { return true; }
   
   #if defined(ARMA_USE_U64S64)
     {
     search_type = get_hdf5_type<u64>();
-    is_equal = ( H5Tequal(datatype, search_type) > 0 );
-    H5Tclose(search_type);
+    is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+    arma_H5Tclose(search_type);
     if (is_equal) { return true; }
     
     search_type = get_hdf5_type<s64>();
-    is_equal = ( H5Tequal(datatype, search_type) > 0 );
-    H5Tclose(search_type);
+    is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+    arma_H5Tclose(search_type);
     if (is_equal) { return true; }
     }
   #endif
@@ -254,13 +255,13 @@ is_supported_arma_hdf5_type(hid_t datatype)
   #if defined(ARMA_ALLOW_LONG)
     {
     search_type = get_hdf5_type<ulng_t>();
-    is_equal = ( H5Tequal(datatype, search_type) > 0 );
-    H5Tclose(search_type);
+    is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+    arma_H5Tclose(search_type);
     if (is_equal) { return true; }
     
     search_type = get_hdf5_type<slng_t>();
-    is_equal = ( H5Tequal(datatype, search_type) > 0 );
-    H5Tclose(search_type);
+    is_equal = ( arma_H5Tequal(datatype, search_type) > 0 );
+    arma_H5Tclose(search_type);
     if (is_equal) { return true; }
     }
   #endif
@@ -298,13 +299,13 @@ hdf5_search_callback
   if (info->type == H5O_TYPE_DATASET)
     {
     // Check type of dataset to see if we could even load it.
-    hid_t dataset  = H5Dopen(loc_id, name, H5P_DEFAULT);
-    hid_t datatype = H5Dget_type(dataset);
+    hid_t dataset  = arma_H5Dopen(loc_id, name, H5P_DEFAULT);
+    hid_t datatype = arma_H5Dget_type(dataset);
     
     const bool is_supported = is_supported_arma_hdf5_type(datatype);
     
-    H5Tclose(datatype);
-    H5Dclose(dataset);
+    arma_H5Tclose(datatype);
+    arma_H5Dclose(dataset);
     
     if(is_supported == false)
       {
@@ -361,7 +362,7 @@ hdf5_search_callback
         if (substring == search_info->names[string_pos])
           {
           // We have found the object; it must be better than our existing match.
-          hid_t match_candidate = H5Dopen(loc_id, name, H5P_DEFAULT);
+          hid_t match_candidate = arma_H5Dopen(loc_id, name, H5P_DEFAULT);
 
 
           // arma_check(match_candidate < 0, "Mat::load(): cannot open an HDF5 dataset");
@@ -372,8 +373,8 @@ hdf5_search_callback
           
           
           // Ensure that the dataset is valid and of the correct dimensionality.
-          hid_t filespace = H5Dget_space(match_candidate);
-          int num_dims = H5Sget_simple_extent_ndims(filespace);
+          hid_t filespace = arma_H5Dget_space(match_candidate);
+          int num_dims = arma_H5Sget_simple_extent_ndims(filespace);
           
           if (num_dims <= search_info->num_dims)
             {
@@ -381,14 +382,14 @@ hdf5_search_callback
             // If we already have an existing match we have to close it.
             if (search_info->best_match != -1)
               {
-              H5Dclose(search_info->best_match);
+              arma_H5Dclose(search_info->best_match);
               }
 
             search_info->best_match_position = string_pos;
             search_info->best_match          = match_candidate;
             }
           
-          H5Sclose(filespace);
+          arma_H5Sclose(filespace);
           }
         }
       
@@ -396,7 +397,7 @@ hdf5_search_callback
       // If they are not the same, but we have not found anything and we don't need an exact match, take this.
       if ((search_info->exact == false) && (search_info->best_match == -1))
         {
-        hid_t match_candidate = H5Dopen(loc_id, name, H5P_DEFAULT);
+        hid_t match_candidate = arma_H5Dopen(loc_id, name, H5P_DEFAULT);
         
         // arma_check(match_candidate < 0, "Mat::load(): cannot open an HDF5 dataset");
         if(match_candidate < 0)
@@ -404,16 +405,16 @@ hdf5_search_callback
           return -1;
           }
         
-        hid_t filespace = H5Dget_space(match_candidate);
-        int num_dims = H5Sget_simple_extent_ndims(filespace);
+        hid_t filespace = arma_H5Dget_space(match_candidate);
+        int num_dims = arma_H5Sget_simple_extent_ndims(filespace);
         
         if (num_dims <= search_info->num_dims)
           {
           // Valid dataset -- we'll keep it.
-          search_info->best_match = H5Dopen(loc_id, name, H5P_DEFAULT);
+          search_info->best_match = arma_H5Dopen(loc_id, name, H5P_DEFAULT);
           }
         
-        H5Sclose(filespace);
+        arma_H5Sclose(filespace);
         }
       }
     }
@@ -443,7 +444,7 @@ search_hdf5_file
   hdf5_search_info search_info = { names, num_dims, exact, -1, names.size() };
   
   // We'll use the H5Ovisit to track potential entries.
-  herr_t status = H5Ovisit(hdf5_file, H5_INDEX_NAME, H5_ITER_NATIVE, hdf5_search_callback, void_ptr(&search_info));
+  herr_t status = arma_H5Ovisit(hdf5_file, H5_INDEX_NAME, H5_ITER_NATIVE, hdf5_search_callback, void_ptr(&search_info));
   
   // Return the best match; it will be -1 if there was a problem.
   return (status < 0) ? -1 : search_info.best_match;
@@ -451,22 +452,20 @@ search_hdf5_file
 
 
 
-//! Load an HDF5 matrix into a Mat of type specified by datatype,
-//! then convert that into the desired matrix 'dest'.
+//! Load an HDF5 matrix into an array of type specified by datatype,
+//! then convert that into the desired array 'dest'.
 //! This should only be called when eT is not the datatype.
 template<typename eT>
 inline
 hid_t
 load_and_convert_hdf5
   (
-  Mat<eT>& dest,
-  hid_t    dataset,
-  hid_t    datatype,
-  hsize_t* dims
+  eT   *dest,
+  hid_t dataset,
+  hid_t datatype,
+  uword n_elem
   )
   {
-  const uword n_rows = dims[0];
-  const uword n_cols = dims[1];
   
   // We can't use nice template specializations here
   // as the determination of the type of 'datatype' must be done at runtime.
@@ -478,14 +477,14 @@ load_and_convert_hdf5
   
   // u8
   search_type = get_hdf5_type<u8>();
-  is_equal = (H5Tequal(datatype, search_type) > 0);
-  H5Tclose(search_type);
+  is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+  arma_H5Tclose(search_type);
   
   if(is_equal)
     {
-    Mat<u8> m(n_rows, n_cols);
-    hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-    dest = conv_to< Mat<eT> >::from(m); // Convert.
+    Col<u8> v(n_elem);
+    hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+    arrayops::convert(dest, v.memptr(), n_elem);
 
     return status;
     }
@@ -493,29 +492,29 @@ load_and_convert_hdf5
   
   // s8
   search_type = get_hdf5_type<s8>();
-  is_equal = (H5Tequal(datatype, search_type) > 0);
-  H5Tclose(search_type);
+  is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+  arma_H5Tclose(search_type);
   
   if(is_equal)
     {
-    Mat<s8> m(n_rows, n_cols);
-    hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-    dest = conv_to< Mat<eT> >::from(m); // Convert.
-    
+    Col<s8> v(n_elem);
+    hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+    arrayops::convert(dest, v.memptr(), n_elem);
+
     return status;
     }
   
   
   // u16
   search_type = get_hdf5_type<u16>();
-  is_equal = (H5Tequal(datatype, search_type) > 0);
-  H5Tclose(search_type);
+  is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+  arma_H5Tclose(search_type);
   
   if(is_equal)
     {
-    Mat<u16> m(n_rows, n_cols);
-    hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-    dest = conv_to< Mat<eT> >::from(m); // Convert.
+    Col<u16> v(n_elem);
+    hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+    arrayops::convert(dest, v.memptr(), n_elem);
 
     return status;
     }
@@ -523,14 +522,14 @@ load_and_convert_hdf5
   
   // s16
   search_type = get_hdf5_type<s16>();
-  is_equal = (H5Tequal(datatype, search_type) > 0);
-  H5Tclose(search_type);
+  is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+  arma_H5Tclose(search_type);
   
   if(is_equal)
     {
-    Mat<s16> m(n_rows, n_cols);
-    hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-    dest = conv_to< Mat<eT> >::from(m); // Convert.
+    Col<s16> v(n_elem);
+    hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+    arrayops::convert(dest, v.memptr(), n_elem);
 
     return status;
     }
@@ -538,14 +537,14 @@ load_and_convert_hdf5
   
   // u32
   search_type = get_hdf5_type<u32>();
-  is_equal = (H5Tequal(datatype, search_type) > 0);
-  H5Tclose(search_type);
+  is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+  arma_H5Tclose(search_type);
   
   if(is_equal)
     {
-    Mat<u32> m(n_rows, n_cols);
-    hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-    dest = conv_to< Mat<eT> >::from(m); // Convert.
+    Col<u32> v(n_elem);
+    hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+    arrayops::convert(dest, v.memptr(), n_elem);
 
     return status;
     }
@@ -553,15 +552,15 @@ load_and_convert_hdf5
   
   // s32
   search_type = get_hdf5_type<s32>();
-  is_equal = (H5Tequal(datatype, search_type) > 0);
-  H5Tclose(search_type);
+  is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+  arma_H5Tclose(search_type);
   
   if(is_equal)
     {
-    Mat<s32> m(n_rows, n_cols);
-    hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-    dest = conv_to< Mat<eT> >::from(m); // Convert.
-    
+    Col<s32> v(n_elem);
+    hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+    arrayops::convert(dest, v.memptr(), n_elem);
+
     return status;
     }
   
@@ -570,29 +569,29 @@ load_and_convert_hdf5
     {
     // u64
     search_type = get_hdf5_type<u64>();
-    is_equal = (H5Tequal(datatype, search_type) > 0);
-    H5Tclose(search_type);
+    is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+    arma_H5Tclose(search_type);
     
     if(is_equal)
       {
-      Mat<u64> m(n_rows, n_cols);
-      hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-      dest = conv_to< Mat<eT> >::from(m); // Convert.
-      
+      Col<u64> v(n_elem);
+      hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+      arrayops::convert(dest, v.memptr(), n_elem);
+
       return status;
       }
     
     
     // s64
     search_type = get_hdf5_type<s64>();
-    is_equal = (H5Tequal(datatype, search_type) > 0);
-    H5Tclose(search_type);
+    is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+    arma_H5Tclose(search_type);
     
     if(is_equal)
       {
-      Mat<s64> m(n_rows, n_cols);
-      hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-      dest = conv_to< Mat<eT> >::from(m); // Convert.
+      Col<s64> v(n_elem);
+      hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+      arrayops::convert(dest, v.memptr(), n_elem);
 
       return status;
       }
@@ -604,30 +603,30 @@ load_and_convert_hdf5
     {
     // ulng_t
     search_type = get_hdf5_type<ulng_t>();
-    is_equal = (H5Tequal(datatype, search_type) > 0);
-    H5Tclose(search_type);
+    is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+    arma_H5Tclose(search_type);
     
     if(is_equal)
       {
-      Mat<ulng_t> m(n_rows, n_cols);
-      hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-      dest = conv_to< Mat<eT> >::from(m); // Convert.
-      
+      Col<ulng_t> v(n_elem);
+      hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+      arrayops::convert(dest, v.memptr(), n_elem);
+
       return status;
       }
     
     
     // slng_t
     search_type = get_hdf5_type<slng_t>();
-    is_equal = (H5Tequal(datatype, search_type) > 0);
-    H5Tclose(search_type);
+    is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+    arma_H5Tclose(search_type);
     
     if(is_equal)
       {
-      Mat<slng_t> m(n_rows, n_cols);
-      hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-      dest = conv_to< Mat<eT> >::from(m); // Convert.
-      
+      Col<slng_t> v(n_elem);
+      hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+      arrayops::convert(dest, v.memptr(), n_elem);
+
       return status;
       }
     }
@@ -636,61 +635,70 @@ load_and_convert_hdf5
   
   // float
   search_type = get_hdf5_type<float>();
-  is_equal = (H5Tequal(datatype, search_type) > 0);
-  H5Tclose(search_type);
+  is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+  arma_H5Tclose(search_type);
   
   if(is_equal)
     {
-    Mat<float> m(n_rows, n_cols);
-    hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-    dest = conv_to< Mat<eT> >::from(m); // Convert.
-    
+    Col<float> v(n_elem);
+    hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+    arrayops::convert(dest, v.memptr(), n_elem);
+
     return status;
     }
   
   
   // double
   search_type = get_hdf5_type<double>();
-  is_equal = (H5Tequal(datatype, search_type) > 0);
-  H5Tclose(search_type);
+  is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+  arma_H5Tclose(search_type);
   
   if(is_equal)
     {
-    Mat<double> m(n_rows, n_cols);
-    hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-    dest = conv_to< Mat<eT> >::from(m); // Convert.
-    
+    Col<double> v(n_elem);
+    hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+    arrayops::convert(dest, v.memptr(), n_elem);
+
     return status;
     }
   
   
   // complex float
   search_type = get_hdf5_type< std::complex<float> >();
-  is_equal = (H5Tequal(datatype, search_type) > 0);
-  H5Tclose(search_type);
+  is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+  arma_H5Tclose(search_type);
   
   if(is_equal)
     {
-    Mat< std::complex<float> > m(n_rows, n_cols);
-    hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-    dest = conv_to< Mat<eT> >::from(m); // Convert.
-
+    if(is_complex<eT>::value == false)
+      {
+      return -1; // can't read complex data into non-complex matrix/cube
+      }
+    
+    Col< std::complex<float> > v(n_elem);
+    hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+    arrayops::convert_cx(dest, v.memptr(), n_elem);
+    
     return status;
     }
   
   
   // complex double
   search_type = get_hdf5_type< std::complex<double> >();
-  is_equal = (H5Tequal(datatype, search_type) > 0);
-  H5Tclose(search_type);
+  is_equal = (arma_H5Tequal(datatype, search_type) > 0);
+  arma_H5Tclose(search_type);
   
   if(is_equal)
     {
-    Mat< std::complex<double> > m(n_rows, n_cols);
-    hid_t status = H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(m.memptr()));
-    dest = conv_to< Mat<eT> >::from(m); // Convert.
+    if(is_complex<eT>::value == false)
+      {
+      return -1; // can't read complex data into non-complex matrix/cube
+      }
+    
+    Col< std::complex<double> > v(n_elem);
+    hid_t status = arma_H5Dread(dataset, datatype, H5S_ALL, H5S_ALL, H5P_DEFAULT, void_ptr(v.memptr()));
+    arrayops::convert_cx(dest, v.memptr(), n_elem);
     
-    H5Tclose(search_type);
     return status;
     }
   
