@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2011 NICTA (www.nicta.com.au)
 // Copyright (C) 2008-2011 Conrad Sanderson
+// Copyright (C) 2008-2011 NICTA (www.nicta.com.au)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -70,6 +70,18 @@ mtOp<out_eT, T1, op_type>::mtOp(const char junk, const T1& in_m, const out_eT in
 
 
 
+template<typename out_eT, typename T1, typename op_type>
+inline
+mtOp<out_eT, T1, op_type>::mtOp(const mtOp_dual_aux_indicator&, const T1& in_m, const typename T1::elem_type in_aux_a, const out_eT in_aux_b)
+  : m         (in_m    )
+  , aux       (in_aux_a)
+  , aux_out_eT(in_aux_b)
+  {
+  arma_extra_debug_sigprint();
+  }
+
+
+
 template<typename out_eT, typename T1, typename op_type>
 inline
 mtOp<out_eT, T1, op_type>::~mtOp()
